The dtcwt library
=================

This library provides support for computing 1D, 2D and 3D dual-tree complex
wavelet transforms and their inverse in Python along with some signal
processing algorithms which make use of the DTCWT.

Contents
````````

.. toctree::
    :maxdepth: 2

    gettingstarted
    transforms
    backends
    algorithms
    examples
    reference

Features of note
````````````````

The features of the ``dtcwt`` library are:

* 1D, 2D and 3D forward and inverse Dual-tree Complex Wavelet Transform
  implementations.
* API similarity with the DTCWT MATLAB toolbox.
* Automatic selection of single versus double precision calculation.
* Built-in support for the most common complex wavelet families.

Licence
```````

The original toolbox is copyrighted and there are some restrictions on use
which are outlined in the file
:download:`ORIGINAL_README.txt<../ORIGINAL_README.txt>`.
Aside from portions directly derived from the original MATLAB toolbox, any
additions in this library and this documentation are licensed under the
2-clause BSD licence as documented in the file
:download:`COPYING.txt<../COPYING.txt>`.

.. vim:sw=4:sts=4:et
